#!/bin/sh
#********************************************************************************
# (c) Copyright [2013-2022] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates 
# and licensors (“Micro Focus”) are as may be set forth in the express warranty 
# statements accompanying such products and services. Nothing herein should be 
# construed as constituting an additional warranty. Micro Focus shall not be liable 
# for technical or editorial errors or omissions contained herein. The information 
# contained herein is subject to change without notice.
#********************************************************************************

#Include library
. /opt/novell/iprintmobile/bin/lib.sh

#Return Code
RVAL=0

#CUPS listen Port
CUPS_LISTEN_PORT="3017"

#Shared Email Settings Info
EMAIL_ID=""
LOGIN_ID=""
PASSWORD=""
IN_SERVER=""
OUT_SERVER=""
ACCESS_METHOD=""

#Global Printing Option Info
BODY_FLAG=""
COLOR_FLAG=""
DUPLEX_FLAG=""
MEDIA_TYPE=""
ORIENTATION_FLAG=""

#Disabling Email flag
EMAIL_DISABLE=""

#IPP Config argument
DEFAULT="--defaultconfig"
ASSIGN_PERMISSION="--assign-permission"

#TOMCAT CLASSPATH VARIABLE PATH
SETENV_PATH="/var/opt/novell/iprint-tomcat/bin/setenv.sh"
SETENV_INSTALL_PATH="/opt/novell/iprintmobile/bin/setenv.sh"
PLATFORM_FILE_PATH="/etc/opt/novell/iprint/conf/iprintconf.properties"

CRONTAB_FILE=/etc/crontab

#Invoking iprintmobile_config via Management console follows the following format.
#iprintmobile_config -L <LibreOffice_port> -C <CUPS_port> -e <Email ID> -u <User ID> -p <Password> -i <Incoming Mail Server> -o <Outgoing Mail Server> -a <Access Method> [-x -c -n -l] -m <Media Type> [-D|-E]

#Invoking iprintmobile_config only for IPP based Submission.
#iprintmobile_config --defaultconfig

#iPrintMobile Initial Config Script Usage
function Usage()
{
	configHeader
	echo "This tool allows complete configuration of iPrint mobile server."
	echo "Use this tool to configure various aspects of $SERVICE_NAME service."  
	echo ""
	echo "--defaultconfig   - Configures the defaults for iPrint Mobile service."
	exit 1
}

function configHeader()
{
        echo  | tee -a "${ERR_LOG}"
        echo "-----------------------------------------------"  | tee -a "${ERR_LOG}"
        echo "$SERVICE_NAME Configuration Tool $VERSION"  | tee -a "${ERR_LOG}"
        echo "-----------------------------------------------"  | tee -a "${ERR_LOG}"
        echo "Start Time: "`date` >> "${ERR_LOG}"
        echo  | tee -a "${ERR_LOG}"
}

#iPrintMobile Pre-configuration Checks
function preConfigurationCheck()
{
	#Check iPrint Mobile Server
	#echo "$INFO Checking Mobile service status..."  | tee -a "${ERR_LOG}"
	#rcnovell-iprint-mobile status >> "${ERR_LOG}" 2>&1
	#if [ $? -eq 0 ] ; then
	#	echo "$FATAL $SERVICE_NAME service is running. Exiting."  | tee -a "${ERR_LOG}"
	#	exit $MOBILE_SERVER_RUNNING
	#fi
	
	#Check if the config file exists
	if [ ! -f $CONF_FILE ] ; then
		#Copy the template as configuration file
		if [ ! -f $CONF_FILE.template ] ; then
			echo "$FATAL Failed to find the template configuration file. Corrupt installation, re-install again." | tee -a "${ERR_LOG}"
			return $INSTALL_ERROR
		else
			cp $CONF_FILE.template $CONF_FILE
		fi
	fi
	
	if [ -f $PLATFORM_FILE_PATH ] ; then
		cat /etc/opt/novell/iprint/conf/iprintconf.properties | grep "platform" | grep "appliance"
		if [ $? -eq 0 ] ; then
			SETENV_PATH="/usr/share/tomcat6/bin/setenv.sh"
		fi
	fi

	#Check setenv.sh file exists
	if [ ! -f $SETENV_PATH ] ; then
		#Copy the setenv file
		cp $SETENV_INSTALL_PATH $SETENV_PATH
		chmod 755 $SETENV_PATH
	fi
	
	if [ -f $CUPS_CONF_FILE ] && [ ! -f $IPRINT_CUPS_CONF_FILE ] ; then
		/usr/bin/systemctl mask cups > /dev/null 2>&1
		systemctl stop $IPRINT_CUPS_SERVICE >> "${ERR_LOG}" 2>&1
		cp $CUPS_CONF_FILE $IPRINT_CUPS_CONF_FILE
		cp /etc/cups/cups-files.conf $IPRINT_CUPSFILES_CONF_FILE
		sed -i '/#ServerRoot/a\ServerRoot /etc/opt/novell/iprintmobile/cups' $IPRINT_CUPSFILES_CONF_FILE >> "${ERR_LOG}" 2>&1
		sh /opt/novell/iprintmobile/bin/set_permissions.sh cups
		systemctl start $IPRINT_CUPS_SERVICE >> "${ERR_LOG}" 2>&1
	fi
	
}

function assignPermissions
{
	chkconfig --add novell-iprint-tomcat >> "${ERR_LOG}" 2>&1
	RVAL=$?
	if [ $RVAL -ne 0 ]; then
		echo "$WARN error while adding novell-iprint-tomcat in service list" | tee -a "${ERR_LOG}"
		exit $RVAL
	fi

	#Enabling iPrint-CUPS for Mobility services
	systemctl enable $IPRINT_CUPS_SERVICE  >> "${ERR_LOG}" 2>&1
	RVAL=$?
	if [ $RVAL -ne 0 ]; then
		echo "$WARN Error while enabling iprint-cups service in service list" | tee -a "${ERR_LOG}"
		exit $RVAL
	fi
	
    grep 'config_driver.sh' /etc/sudoers > /dev/null 2>&1
    if [ $? -ne 0 ]; then
	    sed -i '/User privilege specification/a iprintmobile ALL = NOPASSWD: /opt/novell/iprintmobile/bin/config_driver.sh' /etc/sudoers
    fi
	grep 'lib.sh' /etc/sudoers > /dev/null 2>&1
    if [ $? -ne 0 ]; then
	    sed -i '/User privilege specification/a iprintmobile ALL = NOPASSWD: /opt/novell/iprintmobile/bin/lib.sh' /etc/sudoers
    fi
	exit 0
}

function defaultConfiguration()
{
	#Perform Pre-Configuration Check
	preConfigurationCheck
	
	#Checking cups conflict
	CheckCupsConflict
	if [ $? -ne 0 ] ; then
		echo "$INFO Using 3017 port for CUPS."  | tee -a "${ERR_LOG}"
		#Stop iprint-cups
		systemctl stop $IPRINT_CUPS_SERVICE >> "${ERR_LOG}" 2>&1
		#Save CUPS port
		DEFAULT_CUPS_PORT=3017
		SaveCUPSPort $DEFAULT_CUPS_PORT
		RVAL=$?
		if [ $RVAL -ne 0 ]; then
			exit $RVAL
		fi
		#Start CUPS
		systemctl start $IPRINT_CUPS_SERVICE >> "${ERR_LOG}" 2>&1
		#Lets wait for CUPS to initialize
		sleep 5
		systemctl status $IPRINT_CUPS_SERVICE >> "${ERR_LOG}" 2>&1
		if [ $? -ne 0 ] ; then
			#Restart CUPS only if needed.
			systemctl restart $IPRINT_CUPS_SERVICE >> "${ERR_LOG}" 2>&1
			#Lets wait for CUPS to initialize
			sleep 5
			systemctl status $IPRINT_CUPS_SERVICE >> "${ERR_LOG}" 2>&1
			if [ $? -ne 0 ] ; then
				echo "$FATAL Error occurred while starting CUPS (Error - $CUPS_ERROR)."  | tee -a "${ERR_LOG}"
				exit $CUPS_ERROR
			fi
		fi
	fi

	chkconfig --add novell-iprint-tomcat >> "${ERR_LOG}" 2>&1
	RVAL=$?
	if [ $RVAL -ne 0 ]; then
		echo "$WARN error while adding novell-iprint-tomcat in service list" | tee -a "${ERR_LOG}"
		exit $RVAL
	fi

	#Enabling CUPS for Mobility services
	systemctl enable $IPRINT_CUPS_SERVICE  >> "${ERR_LOG}" 2>&1
	RVAL=$?
	if [ $RVAL -ne 0 ]; then
		echo "$WARN Error while enabling novell-iprint-cups service in service list" | tee -a "${ERR_LOG}"
		exit $RVAL
	fi
    
	grep 'config_driver.sh' /etc/sudoers > /dev/null 2>&1
        if [ $? -ne 0 ]; then
	sed -i '/User privilege specification/a iprintmobile ALL = NOPASSWD: /opt/novell/iprintmobile/bin/config_driver.sh' /etc/sudoers
        fi
		grep 'lib.sh' /etc/sudoers > /dev/null 2>&1
        if [ $? -ne 0 ]; then
	sed -i '/User privilege specification/a iprintmobile ALL = NOPASSWD: /opt/novell/iprintmobile/bin/lib.sh' /etc/sudoers
        fi

	grep "/var/spool/cups/tmp/ -mmin +60 -type f -exec rm -f {}" $CRONTAB_FILE >> /dev/null
	if [ $? -eq 0 ]; then
		echo "Removing old cups cron job entries." | tee -a "${ERR_LOG}"
		sed -i '/cups/d' $CRONTAB_FILE
	fi

	echo "Adding cron job for cups." | tee -a "${ERR_LOG}"
	echo "*/60 * * * * root find /var/spool/cups/tmp/ -mmin +60 -type f -exec rm -f {} \;"  >> $CRONTAB_FILE 
	
	echo "$INFO Configuration completed." | tee -a "${ERR_LOG}"	
	exit 0
}

if [ "$#" -eq "1" ];then
        ARGU=$@
        if [ "$ARGU" == "$DEFAULT" ];then
			defaultConfiguration
			exit $?
		else
			if [ "$ARGU" == "$ASSIGN_PERMISSION" ];then
			    assignPermissions
			    exit $?
		    else
			    Usage
            fi
        fi
else
	Usage
fi
